from setuptools import setup

setup(
   name='super_rockket',
   version='1.0.0',
   author='Rachid el wa3er',
   author_email='rn.benbetka@esi-sba.dz',
   packages=['super_rockket'],
   url='http://pypi.python.org/pypi/super_rockket/',
   license='LICENSE.txt',
   description='An awesome package that does something',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   install_requires=['super_rockket']
)